=================================
Propertyshelf MLS Plone Embedding
=================================

`ps.plone.mls`_ is an add-on for the content management system `Plone`_.
It activates the embedding of real estate listings from the `Propertyshelf`_ MLS.

.. only:: html

  Contents
  ========

.. toctree::
   :maxdepth: 1

   Installation <install>
   Configuration <configuration>
   Listings/Properties <listings/index>
   Development Projects <developments/index>


.. only:: html

  Indices and tables
  ==================

  * :ref:`genindex`
  * :ref:`modindex`
  * :ref:`search`

.. _`Plone`: http://plone.org
.. _`Propertyshelf`: http://propertyshelf.com
.. _`ps.plone.mls`: https://pypi.python.org/pypi/ps.plone.mls
